import { PromptGroupSession } from './PromptGroupSession';
import { IGraphItem } from '../../types';
import { IAgentTool } from '../../types/agents';
import { ToolCall } from '../toolCalls';
/**
 * Manages a collection of prompt group sessions, providing functionalities
 * to start, manage, and retrieve tools for active sessions in xpanderAI.
 */
export declare class PromptGroupSessionsList {
    /** Collection of graph items associated with prompt groups. */
    private graphs;
    /** Array of agent tools specific to prompt groups. */
    pgOas: IAgentTool[];
    /** List of active prompt group sessions. */
    private sessions;
    constructor(
    /** Collection of graph items associated with prompt groups. */
    graphs: IGraphItem[], 
    /** Array of agent tools specific to prompt groups. */
    pgOas: IAgentTool[], 
    /** List of active prompt group sessions. */
    sessions?: PromptGroupSession[]);
    /**
     * Starts a new session for a specified tool call, associating it with a prompt group.
     * If the prompt group or graph cannot be matched, an error is thrown.
     * @param tool - The tool call used to start the prompt group session.
     * @returns A system message indicating the prompt group was successfully selected.
     */
    startPgSession(tool: ToolCall): string;
    /** Returns the currently active session, if one exists. */
    get activeSession(): PromptGroupSession;
    /** Resets all active prompt group sessions. */
    resetSessions(): void;
    /**
     * Determines starting nodes within the graph that are not targeted by other nodes,
     * ensuring that explicitly defined starting nodes are included.
     * @returns A list of starting node names.
     */
    private getStartingNodes;
    /**
     * Retrieves the available tools for the currently active session,
     * filtering tools based on their position in the graph and local tool prefix.
     * @param allTools - A list of all tools available for the session.
     * @returns A filtered list of tools available for the active session.
     */
    getToolsForActiveSession(allTools: any[]): any[];
}
