import { IToolCallPayload, IToolExecutionResult, IToolInstructions, ToolCallType } from '../types';
import { Configuration } from './Configuration';
import { ToolCall } from './toolCalls';
import { SourceNodeType } from '../types/agents';
/**
 * Creates a tool representation for xpanderAI based on tool instructions,
 * formatting description and ensuring parameter fields are included.
 * @param toolInstructions - Instructions containing details about the tool.
 * @returns A tool object structured for use in xpanderAI.
 */
export declare function createTool(toolInstructions: IToolInstructions): any;
/**
 * Executes a specified tool for an agent in xpanderAI, sending a request with
 * the appropriate payload structure including headers, path, query, and body parameters.
 * @param tool - The tool call details.
 * @param agentUrl - The base URL of the agent.
 * @param configuration - Configuration for authentication and custom params.
 * @param sourceNodeType - Source node type for tool operation.
 * @returns The result of the tool execution, parsed as JSON if possible.
 * @throws Error if the response status code indicates failure.
 */
export declare function executeTool(tool: ToolCall, agentUrl: string, configuration: Configuration, sourceNodeType: SourceNodeType): IToolExecutionResult;
/**
 * Generates the base signature for a tool, identifying tool type and presence of
 * prompt group (Pg) functionality based on the tool name.
 * @param toolName - The name of the tool.
 * @param toolCallId - Unique identifier for the tool call.
 * @returns An object containing base details about the tool, such as its type and ID.
 */
export declare function getToolBaseSignature(toolName: string, toolCallId: string): {
    name: string;
    isPg: boolean;
    type: ToolCallType;
    toolCallId: string;
};
export declare function mergeDeep<T>(target: T, source: T): T;
export declare function ensureToolCallPayloadStructure(payload: any): IToolCallPayload;
