import { LLMProvider } from '../../constants/llmProvider';
import { Agent } from '../../core/agents/Agent';
import { ToolCall } from '../../core/toolCalls';
/**
 * BaseLLMProvider serves as the foundational class for integrating different
 * LLM providers, defining common functionality for handling tool extraction
 * and management within an agent.
 */
export declare class BaseLLMProvider {
    agent: Agent;
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Extracts tool calls from an LLM response, if applicable.
     * @param llmResponse - The LLM response object.
     * @returns An array of ToolCall objects extracted from the response.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
    /** Maps original tool names to modified versions, if needed. */
    originalToolNamesReamapping: Record<string, string>;
    constructor(agent: Agent);
    /**
     * Retrieves and organizes tools available for the agent, considering local tools,
     * session-specific tools, and tools for prompt groups.
     * @returns An array of processed tools ready for use.
     * @throws Error if no tools are found for the agent.
     */
    getTools(returnAllTools?: boolean): any[];
    /**
     * Post-processes tools to prepare them for use, applying any necessary modifications.
     * @param tools - The tools to post-process.
     * @returns The processed tools ready for execution.
     */
    postProcessTools(tools: any[]): any[];
}
